@@ -74,7 +74,7 @@ class GetMediaShowItemView(BrowserView):
             return item.absolute_url()
         
         if item.portal_type == 'Image':
-            return item.absolute_url() + '/image_large'
+            return item.absolute_url() + '/image_crop'
         
         if item.portal_type == 'Link' and (item.remoteUrl.find("youtube.com") > -1 or item.remoteUrl.find("vimeo.com") > -1):
             return item.remoteUrl
@@ -88,7 +88,7 @@ class GetMediaShowItemView(BrowserView):
             if len(results) > 0:
                 leadMedia = results[0]
                 if leadMedia.portal_type == 'Image':
-                    return leadMedia.getURL() + '/image_large'
+                    return leadMedia.getURL() + '/image_crop'
                 else:
                     return leadMedia.getURL()
             else:
