@@ -304,7 +304,8 @@ class CommonBrowserView(BrowserView):
         """
         result = []
         workflow = getToolByName(self.context,'portal_workflow')
-        for res in content:
+        sortedContent = sorted(content, key=lambda res: res.portal_type == 'Media Person' and self._normalizePersonName(res.title) or res.title)
+        for res in sortedContent:
             if self.checkPermission(res, 'View'):
                 if res.portal_type == 'Media Person':
                     result.append('<a href="%(link)s" class="%(state_class)s">%(title)s</a>'%{'link':res.absolute_url(), 'title':self._normalizePersonName(res.title), 'state_class': 'state-' + queryUtility(IIDNormalizer).normalize(workflow.getInfoFor(res,'review_state'))})
